name: "oranges_segmentation"
revision: 2
description: "segmentation: resolution 0.5; SVM segmentation (svm_segm_20161004); shape polygon + convex hull"

stages {
  name: "src"
  type: SOURCE_CUSTOM
#  custom_param {
#    proxy: "test:ConcatCustomSource"
#    args: "source_test.apl"
#  }
}

# Reduce image resolution for computational issues
stages {
	name: "src_resize"
	type: RESIZE
	input: "src"
	resize_param {
		fx: 0.5
		fy: 0.5
	}
}

# Perform segmentation with a SVM
stages {
	name: "fg_areas"
	type: SVM_SEGMENTATION
	input: "src_resize"
	svm_segmentation_param {
		#model_file: "models/svm_segm_20161004/model"
                model_file: "models/svm_segm_balls_20161125/model"
		scale: 0.003921568627
	}
}

# Morphological opening to remove the residual segmentation errors
stages {
	name: "morph"
	type: MORPHOLOGY
	input: "fg_areas"
	morphology_param {
		type: OPEN
		iterations_num: 5
		kernel {
			shape_str: "5x5"
			d:0   d:0   d:255 d:0   d:0
			d:0   d:255 d:255 d:255 d:0
			d:255 d:255 d:255 d:255 d:255
			d:0   d:255 d:255 d:255 d:0
			d:0   d:0   d:255 d:0   d:0
		}
	}
}

# Mask resize to return to the original image size
stages {
	name: "bitmask_resize"
	type: RESIZE
	input: "morph"
	resize_param {
		fx: 2
		fy: 2
	}
}

# Remove small and/or big residual areas in the mask
stages {
	name: "remove_areas"
	type: REMOVE_AREAS
	input: "bitmask_resize"
	remove_areas_param {
		threshold_min: 15000
		threshold_max: 100000
	}
}

# Find contours of the objects in the bitmask, optionally fit them with some shapes and associates the results with the BGR image
stages {
	name: "item_shapes"
	type: SEGMENTATION
	input: "src"
	input: "remove_areas"
	segmentation_param {
		type: CONTOURS # CONTOURS; DISTANCE_TRANSFORM
		shape: POLYGON # POLYGON (no fitting); INNER_CIRCLE; OUTER_CIRCLE; RECTANGLE; ROTATED_RECTANGLE; ELLIPSE
		convex_hull: true
		match_parents: true
	}
}

# Cut out the bounding-boxes containing the shapes found in the previous stage. The parameter border_policy regards the cases near the image borders
stages {
	name: "item"
	type: CUT_OUT
	input: "item_shapes"
	cut_out_param {
		type: SQUARED # BOUNDING_BOX; SQUARED
		border_policy: KEEP # KEEP; DISCARD
		margin_x_rel: 0.2 # = 2*left_margin = 2*right_margin
		margin_y_rel: 0.2 # = 2*top_margin = 2*bottom_margin
	}
}
